from .ijazah_terakhir import IjazahTerakhir
from .jam_mengajar import JamMengajar, JamMengajarInduk, JamMengajarNonInduk
from .sekolah_induk import SekolahInduk, LokasiSekolahInduk
from .status_kepegawaian import StatusKepegawaian
from .tugas_tambahan import TugasTambahan
from .data_individu import DataIndividu


__all__ = [
    "IjazahTerakhir",
    "JamMengajar",
    "JamMengajarInduk",
    "JamMengajarNonInduk",
    "SekolahInduk",
    "LokasiSekolahInduk",
    "StatusKepegawaian",
    "TugasTambahan",
    "DataIndividu",
]
